/*
 * Copyright 2007 Evan Cowden
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 */
package org.nakedosgi.annotations.scr;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import static org.nakedosgi.Constants.*;

/**
 * Sister annotation to {@code Bind} to define the <i>SCRUnbind</i> method of
 * a service reference.
 * Evan Cowden
 */
@Documented
@Inherited
@Retention(value = RetentionPolicy.CLASS)
@Target(value = ElementType.METHOD)
public @interface SCRUnbind {

    /**
     * The name of the property reference.  Make 
     * sure that the name used in the {@code SCRUnbind} annotation matches that
     * used in the corresponding {@code Bind} annotation.
     */
    String name() default NO_VALUE;
}
