/*
 * Copyright 2007 Evan Cowden
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 */
package org.nakedosgi.manifest;

import java.util.Collection;
import java.util.Map;
import static org.nakedosgi.manifest.ManifestConstants.*;

/**
 * Builder for OSGi Declarative Services manifest entries
 * Evan Cowden
 */
public class DSManifestBuilder {

    /**
     * <p>
     * Create appropriate manifest entries for OSGi Declarative Services 
     * configuration files.</p>
     * 
     * <p>For each filename specified, this method will append
     * an entry such as:<br/><br/>
     * 
     * {@code Service-Component: <i>filename1</i>, <i>filename2</i>}
     * </p>
     * 
     * <p>Filenames which are already present in the manifest will be 
     * skipped</p>
     * 
     * @param manifest
     * @param componentConfigFiles the filename of OSGi Declarative Services
     * configuration files.
     */
    public static void build(Map<String, String> manifest, Collection<String> componentConfigFiles) {
        for (String filename : componentConfigFiles) {
            Util.appendValue(manifest, SERVICE_COMPONENT_KEY, filename);
        }
    }
}
