/*
 * Copyright 2008 Evan Cowden
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 */
package org.nakedosgi.processor;

import javax.lang.model.element.Element;
import javax.lang.model.element.TypeElement;
import javax.lang.model.type.DeclaredType;
import javax.lang.model.type.TypeMirror;

/**
 * Utilities for parsing code during annotation processing
 * @author Evan Cowden
 */
public class ParsingUtil {

    /**
     * Recursively search for the enclosing class or interface
     * @param element
     * @return the enclosing class or interface, or null if the element is not enclosed by a 
     * class
     */
    public static TypeElement getEnclosingType(Element element) {
        if (element.getKind().isClass() || element.getKind().isInterface()) {
            return (TypeElement) element;
        }

        return getEnclosingType(element.getEnclosingElement());
    }
    
    /**
     * Get the qualified name for a type
     * @param typeMirror a {@code DeclaredType}
     * @return
     */
    public static String getQualifiedName(TypeMirror typeMirror) {
        Element element = ((DeclaredType) typeMirror).asElement();
        TypeElement typeElement = (TypeElement) element;
        return typeElement.getQualifiedName().toString();
    }
}
